@@ -1,15 +1,15 @@
 use v6;
 
-use PDF::DAO::Tie::Hash;
+use PDF::COS::Tie::Hash;
 
 #| AcroForm role - see PDF::Catalog - /AcroForm entry
 role PDF::AcroForm
-    does PDF::DAO::Tie::Hash {
+    does PDF::COS::Tie::Hash {
 
     # see [PDF 1.7 TABLE 8.67 Entries in the interactive form dictionary]
-    use PDF::DAO::Tie;
+    use PDF::COS::Tie;
     use PDF::Field :coerce;
-    use PDF::DAO;
+    use PDF::COS;
 
     has PDF::Field @.Fields is entry(:required, :&coerce);    #| (Required) An array of references to the document’s root fields (those with no ancestors in the field hierarchy).
     #| returns an inorder array of all descendant fields
@@ -52,8 +52,8 @@ role PDF::AcroForm
 
     has UInt $.Q is entry(:alias<quadding>);                     #| (Optional) A document-wide default value for the Q attribute of variable text fields
 
-    use PDF::DAO::Stream;
-    my subset StreamOrArray where PDF::DAO::Stream | Array;
+    use PDF::COS::Stream;
+    my subset StreamOrArray where PDF::COS::Stream | Array;
     has StreamOrArray $.XFA is entry;          #| (Optional; PDF 1.5) A stream or array containing an XFA resource, whose format is described by the Data Package (XDP) Specification. (see the Bibliography).
                                                #| The value of this entry must be either a stream representing the entire contents of the XML Data Package or an array of text string and stream pairs representing the individual packets comprising the XML Data Package
 
